-- (C) 2018 Lucior Gomes
-- Released under the Creative Commons Attribution 4.0 International license
-- (https://creativecommons.org/licenses/by/4.0/)
-- Original source: https://musical-artifacts.com/artifacts/662

ardour {
	["type"] = "EditorAction",
	name = "Create Drumgizmo Tracks",
	author = "PSmith/LGomes",
	description = [[Creates audio tracks - Drumgizmo.]]
} 

function factory () return function ()
	
	local pl = {["Aasimonster"] = "Aasimonster", ["CrocellKit"] = "CrocellKit", ["DRSKit"] = "DRSKit", ["MuldjordKit"] = "MuldjordKit", ["ShittyKit"] = "ShittyKit", ["Sommerhack"] = "Sommerhack"
	}
	local bustype = {["Mono Buses"] = "Mono", ["Stereo Buses"] = "Stereo"
	}
	local dialog_options = {
		{ type = "dropdown", key = "kit", title = "Kit", values = pl, default = "Aasimonster", col = 0 },
		{ type = "checkbox", key = "group", default = true, title = "Group tracks" , col = 1},
		{ type = "entry",    key = "grp_name", col = 2, colspan = 1, default = "Drumgizmo tracks", title = "Group"},
		{ type = "checkbox", key = "stereo_amb_oh", default = true, title = "Ambient & OH on stereo tracks", col = 1},
		{ type = "checkbox", key = "buses", default = true, title = "Send snare and kick tracks to ...", col = 1},
		{ type = "dropdown", key = "bus_t", title = "", values = bustype, default = "Mono Buses",col = 2},
	}
	local rv = LuaDialog.Dialog ("Drumgizmo Tracks Creator", dialog_options):run ()
	if not rv then return end -- cancel
	
	local drumkit = rv["kit"]
	if rv["stereo_amb_oh"] then
		if drumkit == "Aasimonster" then
			names = {
				"OH",
				"Snare top",
				"Snare bottom",
				"Snare trigger",
				"Alesis DM5",
				"Kick right",
				"Kick left",
				"Hihat",
				"Ride cymbal",
				"Tom 1",
				"Tom 2",
				"Tom 3",
				"Tom 4 - floor tom",
				"Ambience"
			}
		elseif drumkit == "CrocellKit" then
			names = {
				"Ambience",
				"OH",
				"OHCenter",
				"Hihat",
				"Ride",
				"SnareTop",
				"SnareBottom",
				"Tom1",
				"Tom2",
				"FTom1",
				"FTom2",
				"KickDrumInside",
				"KickDrumOutside"
			}
		elseif drumkit == "DRSKit" then
			names = {
				"Ambience",
				"Kickdrum back",
				"Kickdrum front",
				"Hihat",
				"OH",
				"Ride cymbal",
				"Snaredrum bottom",
				"Snaredrum top",
				"Tom1",
				"Tom2 (Floor tom)",
				"Tom3 (Floor tom)"
			}
		elseif drumkit == "MuldjordKit" then
			names = {
				"Ambience",
				"Hihat",
				"Kickdrum left",
				"Kickdrum right",
				"OH",
				"Ride left",
				"Ride right",
				"Snare bottom",
				"Snare top",
				"Rack tom 1",
				"Rack tom 2",
				"Rack tom 3",
				"Floor tom",
				"Kick drum trigger signals"
			}
		elseif drumkit == "ShittyKit" then
			names = {
				"Kick",
				"Snare",
				"Tom",
				"Floor tom",
				"OH",
				"Ambience",
			}
		else 
			names = {
				"Clap",
				"Chair",
				"Log",
				"Glass",
				"Camera",
				"Cup",
				"Mug",
				"Snap"
			}
		end
	else	
		if drumkit == "Aasimonster" then
			names = {
				"Overhead left",
				"Overhead right",
				"Snare top",
				"Snare bottom",
				"Snare trigger",
				"Alesis DM5",
				"Kick right",
				"Kick left",
				"Hihat",
				"Ride cymbal",
				"Tom 1",
				"Tom 2",
				"Tom 3",
				"Tom 4 - floor tom",
				"Ambience left",
				"Ambience right"
			}
		elseif drumkit == "CrocellKit" then
			names = {
				"AmbLeft",
				"AmbRight",
				"OHLeft",
				"OHRight",
				"OHCenter",
				"Hihat",
				"Ride",
				"SnareTop",
				"SnareBottom",
				"Tom1",
				"Tom2",
				"FTom1",
				"FTom2",
				"KickDrumInside",
				"KickDrumOutside"
			}
		elseif drumkit == "DRSKit" then
			names = {
				"Ambience left",
				"Ambience right",
				"Kickdrum back",
				"Kickdrum front",
				"Hihat",
				"Overhead left",
				"Overhead right",
				"Ride cymbal",
				"Snaredrum bottom",
				"Snaredrum top",
				"Tom1",
				"Tom2 (Floor tom)",
				"Tom3 (Floor tom)"
			}
		elseif drumkit == "MuldjordKit" then
			names = {
				"Ambience left",
				"Ambience right",
				"Hihat",
				"Kickdrum left",
				"Kickdrum right",
				"Overhead left",
				"Overhead right",
				"Ride left",
				"Ride right",
				"Snare bottom",
				"Snare top",
				"Rack tom 1",
				"Rack tom 2",
				"Rack tom 3",
				"Floor tom",
				"Kick drum trigger signals"
			}
		elseif drumkit == "ShittyKit" then
			names = {
				"Kick",
				"Snare",
				"Tom",
				"Floor tom",
				"OverheadL",
				"OverheadR",
				"RoomL",
				"RoomR"
			}
		else 
			names = {
				"Clap",
				"Chair",
				"Log",
				"Glass",
				"Camera",
				"Cup",
				"Mug",
				"Snap"
			}
		end
	end
	
	if rv['group'] then
	        drum_group = Session:new_route_group(rv['grp_name'])
	end
	
	if rv['buses'] then
		kicktracks = ARDOUR.RouteListPtr () -- create a list
		snaretracks = ARDOUR.RouteListPtr () -- create a list
	end
	
	local color = 0xff8800ff  --orange

	local i = 1
	while names[i] do
		if (drumkit == "Sommerhack" or names[i] == "Ambience" or names[i] == "OH") then
			tl = Session:new_audio_track (2, 2, nil, 1, names[i],
		     	ARDOUR.PresentationInfo.max_order,
		     	ARDOUR.TrackMode.Normal)
		else
			tl = Session:new_audio_track (1, 2, nil, 1, names[i],
		     	ARDOUR.PresentationInfo.max_order,
		     	ARDOUR.TrackMode.Normal)
		end
		for track in tl:iter () do
			track:presentation_info_ptr ():set_color (color)
			if rv['group'] then
				drum_group:add(track)
			end
			if (rv['buses'] and string.find(names[i], "Kick") ~= nil) then
				kicktracks:push_back (track)
			end
			if (rv['buses'] and string.find(names[i], "Snare") ~= nil) then
				snaretracks:push_back (track)
			end
		end
		
			i = i + 1
	end --foreach track
		
	if rv['buses'] and (drumkit == "Aasimonster" or drumkit == "CrocellKit" or drumkit == "DRSKit" or drumkit == "MuldjordKit") then
		if rv['bus_t'] == "Mono" then   
	     		kickbus = Session:new_audio_route (1, 2, nil, 1, "Kick Bus", ARDOUR.PresentationInfo.Flag.AudioBus, ARDOUR.PresentationInfo.max_order)
	        	Session:add_internal_sends (kickbus:front (), ARDOUR.Placement.PostFader, kicktracks);
	        	snarebus = Session:new_audio_route (1, 2, nil, 1, "Snare Bus", ARDOUR.PresentationInfo.Flag.AudioBus, ARDOUR.PresentationInfo.max_order)
	        	Session:add_internal_sends (snarebus:front (), ARDOUR.Placement.PostFader, snaretracks);
		else
			kickbus = Session:new_audio_route (2, 2, nil, 1, "Kick Bus", ARDOUR.PresentationInfo.Flag.AudioBus, ARDOUR.PresentationInfo.max_order)
	        	Session:add_internal_sends (kickbus:front (), ARDOUR.Placement.PostFader, kicktracks);
	        	snarebus = Session:new_audio_route (2, 2, nil, 1, "Snare Bus", ARDOUR.PresentationInfo.Flag.AudioBus, ARDOUR.PresentationInfo.max_order)
	        	Session:add_internal_sends (snarebus:front (), ARDOUR.Placement.PostFader, snaretracks);
	    	end	 
 	end

end end -- function factory
